# Projects

## Overview

This maintains a list of projects where IESopt was applied as part of the modeling
approach. Entries are in alphabetical order. If you want to contribute a new project, please follow the
instructions in the [section on contributing](#contributing) below.

## List of references

To be added.

## Contributing

To contribute a new reference, either

- fork the [iesopt](https://github.com/ait-energy/iesopt) repository, and directly add to the above list, or
- open an issue with the reference details.

See the template below for the structure of a reference.

### Template

To be added.

### Creating citation badges

You can use [shields.io](https://shields.io/badges) to create badges, or use standardized ones that you already have
(e.g., from Zenodo), otherwise stick to the ones provided below.

**Pure:** _(publications.ait.ac.at)_

> ```markdown
> [![CITATION](https://img.shields.io/badge/PURE-publications.ait.ac.at-none?style=social)](ADDYOURLINKHERE)
> ```

**DOI:**

> ```markdown
> [![CITATION](https://img.shields.io/badge/DOI-10.XXXX%2Fname.YYYY.ZZZZZZ-none?style=social)](https://doi.org/10.XXXX/name.YYYY.ZZZZZZ)
> ```
